==> SD35B_0.03.0_src.tar.gz: Sd35b/decoder/CommandDriverF.cpp <==
/*
 * CommandDriverF.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 *      99/05/24 KISAKA Toshihiro       modify for mwcc compatiblility
 *
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
using namespace ALSD;
using namespace ALSD_CMDDRV;
using namespace std;
#endif
/**********************************************************************
	F command
**********************************************************************/
void CCommandDriver::_CommandF(void)
{
	switch( m_lpSD->GetParser()->GetC() ){
		case 1:
			CommandF1(); break;
		case 2:
			CommandF2(); break;
		case 3:
			CommandF3(); break;
		case 4:
			CommandF4(); break;
		case 5:
			CommandF5(); break;
		case 6:
			CommandF6(); break;
		case 7:
			CommandF7(); break;
		default:
			throw EALSD_Msg( "error: F? unknown command\n" );
			break;
	}
}
/**********************************************************************
	e[uf[^擾(x[XړAItZbgw)
**********************************************************************/
void CCommandDriver::CommandF1( void )
{
	long str_number	= m_lpED->GetExpValue() - 1;
	long skip		= m_lpED->GetExpValue();

	// ǂݍ݃AhXړĂ
	long address = m_lpSD->GetParser()->GetAddress();
	m_lpSD->GetParser()->NearJamp( m_DataTableAddress );
	
	string work;
	while( skip-- )m_lpSD->GetParser()->GetString( work, 0 );
	m_lpSD->GetParser()->GetString( work, 0 );
	strcpy( m_lpED->GetStrVariable( str_number ), work.c_str() );
	
	m_DataTableAddress = m_lpSD->GetParser()->GetAddress();
	m_lpSD->GetParser()->NearJamp( address );
	
	TRACE( "command:F1( ... )\n" );
}
/**********************************************************************
	e[uf[^l擾(x[XړAItZbgw)
**********************************************************************/
void CCommandDriver::CommandF2( void )
{
	long *read_var	= m_lpED->GetVariableNo();
	long skip		= m_lpED->GetExpValue();

	m_DataTableAddress += skip * 2;
	*read_var = m_lpSD->GetParser()->GetRW( m_DataTableAddress );
	m_DataTableAddress += 2;
	
	TRACE( "command:F2( ... )\n" );
}
/**********************************************************************
	e[uf[^l擾(x[XŒAItZbgw)
**********************************************************************/
void CCommandDriver::CommandF3( void )
{
	long *read_var	= m_lpED->GetVariableNo();
	long skip		= m_lpED->GetExpValue();
	
	*read_var = m_lpSD->GetParser()->GetRW( m_DataTableAddress + skip * 2 );
	TRACE( "command:F3( ... )\n" );
}
/**********************************************************************
	e[uf[^l擾(x[XړAw)
**********************************************************************/
void CCommandDriver::CommandF4( void )
{
	long *read_var	= m_lpED->GetVariableNo();
	long count		= m_lpED->GetExpValue();
	
	for( int i = 0; i < count; i++ ){
		read_var[i] = m_lpSD->GetParser()->GetRW( m_DataTableAddress );
		m_DataTableAddress += 2;
	}
	TRACE( "command:F4( ... )\n" );
}
/**********************************************************************
**********************************************************************/
void CCommandDriver::CommandF5( void )
{
	TRACE( "error:No implement... /" );
	TRACE( "command:F5( ... )\n" );
}
void CCommandDriver::CommandF6( void )
{
	TRACE( "error:No implement... /" );
	TRACE( "command:F6( ... )\n" );
}
void CCommandDriver::CommandF7( void )
{
	TRACE( "error:No implement... /" );
	TRACE( "command:F7( ... )\n" );
}

==> SD35B_0.03.1_src.tar.gz: Sd35b/decoder/CommandDriverF.cpp <==
/*
 * CommandDriverF.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 *      99/05/24 KISAKA Toshihiro       modify for mwcc compatiblility
 *
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
using namespace ALSD;
using namespace ALSD_CMDDRV;
using namespace std;
#endif
/**********************************************************************
	F command
**********************************************************************/
void CCommandDriver::_CommandF(void)
{
	switch( m_lpSD->GetParser()->GetC() ){
		case 1:
			CommandF1(); break;
		case 2:
			CommandF2(); break;
		case 3:
			CommandF3(); break;
		case 4:
			CommandF4(); break;
		case 5:
			CommandF5(); break;
		case 6:
			CommandF6(); break;
		case 7:
			CommandF7(); break;
		default:
			throw EALSD_Msg( "error: F? unknown command\n" );
			break;
	}
}
/**********************************************************************
	e[uf[^擾(x[XړAItZbgw)
**********************************************************************/
void CCommandDriver::CommandF1( void )
{
	long str_number	= m_lpED->GetExpValue() - 1;
	long skip		= m_lpED->GetExpValue();

	// ǂݍ݃AhXړĂ
	long address = m_lpSD->GetParser()->GetAddress();
	m_lpSD->GetParser()->NearJamp( m_DataTableAddress );
	
	string work;
	while( skip-- )m_lpSD->GetParser()->GetString( work, 0 );
	m_lpSD->GetParser()->GetString( work, 0 );
	strcpy( m_lpED->GetStrVariable( str_number ), work.c_str() );
	
	m_DataTableAddress = m_lpSD->GetParser()->GetAddress();
	m_lpSD->GetParser()->NearJamp( address );
	
	TRACE( "command:F1( %s )\n", work.c_str() );
}
/**********************************************************************
	e[uf[^l擾(x[XړAItZbgw)
**********************************************************************/
void CCommandDriver::CommandF2( void )
{
	long *read_var	= m_lpED->GetVariableNo();
	long skip		= m_lpED->GetExpValue();

	m_DataTableAddress += skip * 2;
	*read_var = m_lpSD->GetParser()->GetRW( m_DataTableAddress );
	m_DataTableAddress += 2;
	
	TRACE( "command:F2( ... )\n" );
}
/**********************************************************************
	e[uf[^l擾(x[XŒAItZbgw)
**********************************************************************/
void CCommandDriver::CommandF3( void )
{
	long *read_var	= m_lpED->GetVariableNo();
	long skip		= m_lpED->GetExpValue();
	
	*read_var = m_lpSD->GetParser()->GetRW( m_DataTableAddress + skip * 2 );
	TRACE( "command:F3( ... )\n" );
}
/**********************************************************************
	e[uf[^l擾(x[XړAw)
**********************************************************************/
void CCommandDriver::CommandF4( void )
{
	long *read_var	= m_lpED->GetVariableNo();
	long count		= m_lpED->GetExpValue();
	
	for( int i = 0; i < count; i++ ){
		read_var[i] = m_lpSD->GetParser()->GetRW( m_DataTableAddress );
		m_DataTableAddress += 2;
	}
	TRACE( "command:F4( ... )\n" );
}
/**********************************************************************
**********************************************************************/
void CCommandDriver::CommandF5( void )
{
	TRACE( "error:No implement... /" );
	TRACE( "command:F5( ... )\n" );
}
void CCommandDriver::CommandF6( void )
{
	TRACE( "error:No implement... /" );
	TRACE( "command:F6( ... )\n" );
}
void CCommandDriver::CommandF7( void )
{
	TRACE( "error:No implement... /" );
	TRACE( "command:F7( ... )\n" );
}
